Determine Model Type
determine_model_type.RdClassifies the type of model (SEM vs DCM) explicitly by evaluating the structure of the latent attributes and tasks.

determine_model_type.RdClassifies the type of model (SEM vs DCM) explicitly by evaluating the structure of the latent attributes and tasks.