Skip to contents

Extracts the vertex attributes from an igraph object and formats them into a standardized nodes data.frame.

Usage

get_NodesTable(graph)

Arguments

graph

An igraph object.

Value

A data.frame containing the nodes with columns id, type, compute, and optionally description.