Extract Graph Information
get_graph_info.RdEvaluates the igraph object to extract dimensional structural properties,
adjacency matrices, and compute rules required for Nimble configuration.

get_graph_info.RdEvaluates the igraph object to extract dimensional structural properties,
adjacency matrices, and compute rules required for Nimble configuration.