Configure DCM Initialization and Constants
configure_dcm.RdGenerates the necessary Nimble constants, inits, and monitors
specifically tailored for Diagnostic Classification Models (DCMs).
Arguments
- info
Graph structural properties from
get_graph_info.- X
A numeric matrix representing the observational participant data.
- priors
Optional list of prior specifications. Can be provided as common pairs (e.g.,
list(beta = c(mean, std), theta = c(mean, std), lambda = c(mean, std))) or individual parameter arrays (e.g.,list(beta_mean = c(...), beta_std = c(...), theta_mean = matrix(...), ...)). IfNULL, default priors (mean 0, std 2) are generated. Passing a standard deviation of0.0001or similar effectively acts as a point distribution, enabling the use ofpgdcmas a scoring-only model when parameter means are supplied from a previous calibration.