Get Cytoscape Template
get_Cyto_template.RdCopies the bundled PGDCM Cytoscape template file to the current working directory.
Usage
get_Cyto_template(dest_dir = getwd(), overwrite = FALSE)
get_Cyto_template.RdCopies the bundled PGDCM Cytoscape template file to the current working directory.
get_Cyto_template(dest_dir = getwd(), overwrite = FALSE)