get_EdgesTable.Rd
Extracts the edge list from an igraph object and formats it into a standardized edges data.frame.
igraph
data.frame
get_EdgesTable(graph)
An igraph object.
A data.frame containing the edges with columns source and target.
source
target