Extract Nodes Table from Graph
get_NodesTable.RdExtracts the vertex attributes from an igraph object and formats them
into a standardized nodes data.frame.

get_NodesTable.RdExtracts the vertex attributes from an igraph object and formats them
into a standardized nodes data.frame.